@@ -3,6 +3,10 @@ print(f"{'@'*50} {__file__}")
 
 # ============================================================ APIs.
 from idebug._print import *
+from idebug._print import (
+    _dict,
+    _dir,
+)
 
 
 
